///Autor: Torley
///Erstellungsdatum: 2010-03-09
///Funktion: 
///Hauptklasse der OpenAnt!'s hier werden die Handler verwaltet
///In dieser Klasse sollte nichts mit der Ameise getan werden. 
using System;
using AntMe.Deutsch;
using System.Collections;
using System.Collections.Generic;

namespace AntMe.Spieler.OpenAnt
{
    [Spieler(
        Volkname = "OpenAnt!",
        Vorname = "AntMe!",
        Nachname = "Community"
    )]

    [Kaste(
        Name = "Sammler",
        GeschwindigkeitModifikator = 0,
        DrehgeschwindigkeitModifikator = -1,
        LastModifikator = 2,
        ReichweiteModifikator = 0,
        SichtweiteModifikator = 1,
        EnergieModifikator = -1,
        AngriffModifikator = -1
    )]

    public class OpenAnt : Basisameise
    {
        ArrayList Handler = new ArrayList();

        #region Kaste
        public override string BestimmeKaste(Dictionary<string, int> anzahl)
        {
            string strErmittelteKaste = "Sammler";

            /* Kurzerklrung zu Handler:
             * Jede Ameise hat ihre eigenen Handler,
             * In den Funktionen die von AntMe! aufgerufen werden, werden nacheinander die Handler abgeklappert. 
             * Die Funktionen der Handler (IAmeie) haben Rckgabewerte, 
             * ist der Bool auf true nach der Behandlung durch einen Handler, so wird kein weiterer Handler durchlaufen.
             * -> True: Handler hat bereits etwas gemacht, was nicht abgebrochen werden sollte
             * -> False: Ich hab nichts oder nichts wichtiges gemacht, du darfst.
            */
            //Allgemeine Handler
            //Hier kommen Handler hin, die jede Ameisen macht z.B. Globalen Gedchnis neuen Zucker melden
            Handler.Add(new Eigenschaften.RichtigesWirdMuede(this));
            Handler.Add(new Eigenschaften.MeldeNahrung(this));

            //Kastenspezifische Handler
            //Hier kommen Handler hin, die die Ameise steuern bzw bestimmte Verhalten angeben
            switch (strErmittelteKaste)
            {
                case "Sammler":
                    {
                        //Obstammeln vor Zuckersammekn. Ist kein Obst mehr vorhanden greift das Zuckersammeln
                        Handler.Add(new Eigenschaften.ObstSammeln(this));
                        Handler.Add(new Eigenschaften.ZuckerSammeln(this));
                        Handler.Add(new Eigenschaften.InSternFormAuslaufen(this));
                        break;
                    }
            }

            return strErmittelteKaste;
        }

        #endregion

        #region Fortbewegung
        public override void Wartet()
        {
            for (int i = 0; i < Handler.Count; i++)
            {
                if (((IAmeise)Handler[i]).Wartet())
                {
                    break;
                }
            }
        }

        public override void WirdMde()
        {
            for (int i = 0; i < Handler.Count; i++)
            {
                if (((IAmeise)Handler[i]).WirdMde())
                {
                    break;
                }
            }
        }

        #endregion

        #region Nahrung
        public override void Sieht(Zucker zucker)
        {
            for (int i = 0; i < Handler.Count; i++)
            {
                if (((IAmeise)Handler[i]).Sieht(zucker))
                {
                    break;
                }
            }
        }

        public override void Sieht(Obst obst)
        {
            for (int i = 0; i < Handler.Count; i++)
            {
                if (((IAmeise)Handler[i]).Sieht(obst))
                {
                    break;
                }
            }
        }

        public override void ZielErreicht(Zucker zucker)
        {
            for (int i = 0; i < Handler.Count; i++)
            {
                if (((IAmeise)Handler[i]).ZielErreicht(zucker))
                {
                    break;
                }
            }
        }

        public override void ZielErreicht(Obst obst)
        {
            for (int i = 0; i < Handler.Count; i++)
            {
                if (((IAmeise)Handler[i]).ZielErreicht(obst))
                {
                    break;
                }
            }
        }

        #endregion

        #region Kommunikation

        public override void RiechtFreund(Markierung markierung)
        {
            for (int i = 0; i < Handler.Count; i++)
            {
                if (((IAmeise)Handler[i]).RiechtFreund(markierung))
                {
                    break;
                }
            }
        }

        public override void SiehtFreund(Ameise ameise)
        {
            for (int i = 0; i < Handler.Count; i++)
            {
                if (((IAmeise)Handler[i]).SiehtFreund(ameise))
                {
                    break;
                }
            }
        }

        public override void SiehtVerbndeten(Ameise ameise)
        {
            for (int i = 0; i < Handler.Count; i++)
            {
                if (((IAmeise)Handler[i]).SiehtVerbndeten(ameise))
                {
                    break;
                }
            }
        }

        #endregion

        #region Kampf

        public override void SiehtFeind(Wanze wanze)
        {
            for (int i = 0; i < Handler.Count; i++)
            {
                if (((IAmeise)Handler[i]).SiehtFeind(wanze))
                {
                    break;
                }
            }
        }

        public override void SiehtFeind(Ameise ameise)
        {
            for (int i = 0; i < Handler.Count; i++)
            {
                if (((IAmeise)Handler[i]).SiehtFeind(ameise))
                {
                    break;
                }
            }
        }

        public override void WirdAngegriffen(Wanze wanze)
        {
            for (int i = 0; i < Handler.Count; i++)
            {
                if (((IAmeise)Handler[i]).WirdAngegriffen(wanze))
                {
                    break;
                }
            }
        }

        public override void WirdAngegriffen(Ameise ameise)
        {
            for (int i = 0; i < Handler.Count; i++)
            {
                if (((IAmeise)Handler[i]).WirdAngegriffen(ameise))
                {
                    break;
                }
            }
        }

        #endregion

        #region Sonstiges

        public override void IstGestorben(Todesart todesart)
        {
            for (int i = 0; i < Handler.Count; i++)
            {
                if (((IAmeise)Handler[i]).IstGestorben(todesart))
                {
                    break;
                }
            }
        }

        public override void Tick()
        {
            for (int i = 0; i < Handler.Count; i++)
            {
                if (((IAmeise)Handler[i]).Tick())
                {
                    break;
                }
            }
        }

        #endregion

    }
}